'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def invoke_endpoint(EndpointName=None, Body=None, ContentType=None, Accept=None, CustomAttributes=None, TargetModel=None):
    """
    After you deploy a model into production using Amazon SageMaker hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint.
    For an overview of Amazon SageMaker, see How It Works .
    Amazon SageMaker strips all POST headers except those supported by the API. Amazon SageMaker might add additional headers. You should not rely on the behavior of headers outside those enumerated in the request syntax.
    Calls to InvokeEndpoint are authenticated by using AWS Signature Version 4. For information, see Authenticating Requests (AWS Signature Version 4) in the Amazon S3 API Reference .
    A customer\'s model containers must respond to requests within 60 seconds. The model itself can have a maximum processing time of 60 seconds before responding to the /invocations. If your model is going to take 50-60 seconds of processing time, the SDK socket timeout should be set to be 70 seconds.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.invoke_endpoint(
        EndpointName='string',
        Body=b'bytes'|file,
        ContentType='string',
        Accept='string',
        CustomAttributes='string',
        TargetModel='string'
    )
    
    
    :type EndpointName: string
    :param EndpointName: [REQUIRED]\nThe name of the endpoint that you specified when you created the endpoint using the CreateEndpoint API.\n

    :type Body: bytes or seekable file-like object
    :param Body: [REQUIRED]\nProvides input data, in the format specified in the ContentType request header. Amazon SageMaker passes all of the data in the body to the model.\nFor information about the format of the request body, see Common Data Formats\xe2\x80\x94Inference .\n

    :type ContentType: string
    :param ContentType: The MIME type of the input data in the request body.

    :type Accept: string
    :param Accept: The desired MIME type of the inference in the response.

    :type CustomAttributes: string
    :param CustomAttributes: Provides additional information about a request for an inference submitted to a model hosted at an Amazon SageMaker endpoint. The information is an opaque value that is forwarded verbatim. You could use this value, for example, to provide an ID that you can use to track a request or to provide other metadata that a service endpoint was programmed to process. The value must consist of no more than 1024 visible US-ASCII characters as specified in Section 3.3.6. Field Value Components of the Hypertext Transfer Protocol (HTTP/1.1). This feature is currently supported in the AWS SDKs but not in the Amazon SageMaker Python SDK.

    :type TargetModel: string
    :param TargetModel: Specifies the model to be requested for an inference when invoking a multi-model endpoint.

    :rtype: dict

ReturnsResponse Syntax
{
    'Body': StreamingBody(),
    'ContentType': 'string',
    'InvokedProductionVariant': 'string',
    'CustomAttributes': 'string'
}


Response Structure

(dict) --

Body (StreamingBody) --
Includes the inference provided by the model.
For information about the format of the response body, see Common Data Formats\xe2\x80\x94Inference .

ContentType (string) --
The MIME type of the inference returned in the response body.

InvokedProductionVariant (string) --
Identifies the production variant that was invoked.

CustomAttributes (string) --
Provides additional information in the response about the inference returned by a model hosted at an Amazon SageMaker endpoint. The information is an opaque value that is forwarded verbatim. You could use this value, for example, to return an ID received in the CustomAttributes header of a request or other metadata that a service endpoint was programmed to produce. The value must consist of no more than 1024 visible US-ASCII characters as specified in Section 3.3.6. Field Value Components of the Hypertext Transfer Protocol (HTTP/1.1). If the customer wants the custom attribute returned, the model must set the custom attribute to be included on the way back.
This feature is currently supported in the AWS SDKs but not in the Amazon SageMaker Python SDK.







Exceptions

SageMakerRuntime.Client.exceptions.InternalFailure
SageMakerRuntime.Client.exceptions.ServiceUnavailable
SageMakerRuntime.Client.exceptions.ValidationError
SageMakerRuntime.Client.exceptions.ModelError


    :return: {
        'Body': StreamingBody(),
        'ContentType': 'string',
        'InvokedProductionVariant': 'string',
        'CustomAttributes': 'string'
    }
    
    
    :returns: 
    SageMakerRuntime.Client.exceptions.InternalFailure
    SageMakerRuntime.Client.exceptions.ServiceUnavailable
    SageMakerRuntime.Client.exceptions.ValidationError
    SageMakerRuntime.Client.exceptions.ModelError
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_project(name=None, region=None, contents=None, snapshotId=None):
    """
    Creates an AWS Mobile Hub project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_project(
        name='string',
        region='string',
        contents=b'bytes'|file,
        snapshotId='string'
    )
    
    
    :type name: string
    :param name: Name of the project.

    :type region: string
    :param region: Default region where project resources should be created.

    :type contents: bytes or seekable file-like object
    :param contents: ZIP or YAML file which contains configuration settings to be used when creating the project. This may be the contents of the file downloaded from the URL provided in an export project operation.

    :type snapshotId: string
    :param snapshotId: Unique identifier for an exported snapshot of project configuration. This snapshot identifier is included in the share URL when a project is exported.

    :rtype: dict

ReturnsResponse Syntax
{
    'details': {
        'name': 'string',
        'projectId': 'string',
        'region': 'string',
        'state': 'NORMAL'|'SYNCING'|'IMPORTING',
        'createdDate': datetime(2015, 1, 1),
        'lastUpdatedDate': datetime(2015, 1, 1),
        'consoleUrl': 'string',
        'resources': [
            {
                'type': 'string',
                'name': 'string',
                'arn': 'string',
                'feature': 'string',
                'attributes': {
                    'string': 'string'
                }
            },
        ]
    }
}


Response Structure

(dict) --
Result structure used in response to a request to create a project.

details (dict) --
Detailed information about the created AWS Mobile Hub project.

name (string) --
Name of the project.

projectId (string) --
Unique project identifier.

region (string) --
Default region to use for AWS resource creation in the AWS Mobile Hub project.

state (string) --
Synchronization state for a project.

createdDate (datetime) --
Date the project was created.

lastUpdatedDate (datetime) --
Date of the last modification of the project.

consoleUrl (string) --
Website URL for this project in the AWS Mobile Hub console.

resources (list) --
List of AWS resources associated with a project.

(dict) --
Information about an instance of an AWS resource associated with a project.

type (string) --
Simplified name for type of AWS resource (e.g., bucket is an Amazon S3 bucket).

name (string) --
Name of the AWS resource (e.g., for an Amazon S3 bucket this is the name of the bucket).

arn (string) --
AWS resource name which uniquely identifies the resource in AWS systems.

feature (string) --
Identifies which feature in AWS Mobile Hub is associated with this AWS resource.

attributes (dict) --
Key-value attribute pairs.

(string) --
Key part of key-value attribute pairs.

(string) --
Value part of key-value attribute pairs.

















Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException
Mobile.Client.exceptions.LimitExceededException


    :return: {
        'details': {
            'name': 'string',
            'projectId': 'string',
            'region': 'string',
            'state': 'NORMAL'|'SYNCING'|'IMPORTING',
            'createdDate': datetime(2015, 1, 1),
            'lastUpdatedDate': datetime(2015, 1, 1),
            'consoleUrl': 'string',
            'resources': [
                {
                    'type': 'string',
                    'name': 'string',
                    'arn': 'string',
                    'feature': 'string',
                    'attributes': {
                        'string': 'string'
                    }
                },
            ]
        }
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    Mobile.Client.exceptions.NotFoundException
    Mobile.Client.exceptions.LimitExceededException
    
    """
    pass

def delete_project(projectId=None):
    """
    Delets a project in AWS Mobile Hub.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_project(
        projectId='string'
    )
    
    
    :type projectId: string
    :param projectId: [REQUIRED]\nUnique project identifier.\n

    :rtype: dict
ReturnsResponse Syntax{
    'deletedResources': [
        {
            'type': 'string',
            'name': 'string',
            'arn': 'string',
            'feature': 'string',
            'attributes': {
                'string': 'string'
            }
        },
    ],
    'orphanedResources': [
        {
            'type': 'string',
            'name': 'string',
            'arn': 'string',
            'feature': 'string',
            'attributes': {
                'string': 'string'
            }
        },
    ]
}


Response Structure

(dict) --Result structure used in response to request to delete a project.

deletedResources (list) --Resources which were deleted.

(dict) --Information about an instance of an AWS resource associated with a project.

type (string) --Simplified name for type of AWS resource (e.g., bucket is an Amazon S3 bucket).

name (string) --Name of the AWS resource (e.g., for an Amazon S3 bucket this is the name of the bucket).

arn (string) --AWS resource name which uniquely identifies the resource in AWS systems.

feature (string) --Identifies which feature in AWS Mobile Hub is associated with this AWS resource.

attributes (dict) --Key-value attribute pairs.

(string) --Key part of key-value attribute pairs.

(string) --Value part of key-value attribute pairs.









orphanedResources (list) --Resources which were not deleted, due to a risk of losing potentially important data or files.

(dict) --Information about an instance of an AWS resource associated with a project.

type (string) --Simplified name for type of AWS resource (e.g., bucket is an Amazon S3 bucket).

name (string) --Name of the AWS resource (e.g., for an Amazon S3 bucket this is the name of the bucket).

arn (string) --AWS resource name which uniquely identifies the resource in AWS systems.

feature (string) --Identifies which feature in AWS Mobile Hub is associated with this AWS resource.

attributes (dict) --Key-value attribute pairs.

(string) --Key part of key-value attribute pairs.

(string) --Value part of key-value attribute pairs.














Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.NotFoundException


    :return: {
        'deletedResources': [
            {
                'type': 'string',
                'name': 'string',
                'arn': 'string',
                'feature': 'string',
                'attributes': {
                    'string': 'string'
                }
            },
        ],
        'orphanedResources': [
            {
                'type': 'string',
                'name': 'string',
                'arn': 'string',
                'feature': 'string',
                'attributes': {
                    'string': 'string'
                }
            },
        ]
    }
    
    
    """
    pass

def describe_bundle(bundleId=None):
    """
    Get the bundle details for the requested bundle id.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_bundle(
        bundleId='string'
    )
    
    
    :type bundleId: string
    :param bundleId: [REQUIRED]\nUnique bundle identifier.\n

    :rtype: dict
ReturnsResponse Syntax{
    'details': {
        'bundleId': 'string',
        'title': 'string',
        'version': 'string',
        'description': 'string',
        'iconUrl': 'string',
        'availablePlatforms': [
            'OSX'|'WINDOWS'|'LINUX'|'OBJC'|'SWIFT'|'ANDROID'|'JAVASCRIPT',
        ]
    }
}


Response Structure

(dict) --Result structure contains the details of the bundle.

details (dict) --The details of the bundle.

bundleId (string) --Unique bundle identifier.

title (string) --Title of the download bundle.

version (string) --Version of the download bundle.

description (string) --Description of the download bundle.

iconUrl (string) --Icon for the download bundle.

availablePlatforms (list) --Developer desktop or mobile app or website platforms.

(string) --Developer desktop or target mobile app or website platform.










Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException


    :return: {
        'details': {
            'bundleId': 'string',
            'title': 'string',
            'version': 'string',
            'description': 'string',
            'iconUrl': 'string',
            'availablePlatforms': [
                'OSX'|'WINDOWS'|'LINUX'|'OBJC'|'SWIFT'|'ANDROID'|'JAVASCRIPT',
            ]
        }
    }
    
    
    """
    pass

def describe_project(projectId=None, syncFromResources=None):
    """
    Gets details about a project in AWS Mobile Hub.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_project(
        projectId='string',
        syncFromResources=True|False
    )
    
    
    :type projectId: string
    :param projectId: [REQUIRED]\nUnique project identifier.\n

    :type syncFromResources: boolean
    :param syncFromResources: If set to true, causes AWS Mobile Hub to synchronize information from other services, e.g., update state of AWS CloudFormation stacks in the AWS Mobile Hub project.

    :rtype: dict

ReturnsResponse Syntax
{
    'details': {
        'name': 'string',
        'projectId': 'string',
        'region': 'string',
        'state': 'NORMAL'|'SYNCING'|'IMPORTING',
        'createdDate': datetime(2015, 1, 1),
        'lastUpdatedDate': datetime(2015, 1, 1),
        'consoleUrl': 'string',
        'resources': [
            {
                'type': 'string',
                'name': 'string',
                'arn': 'string',
                'feature': 'string',
                'attributes': {
                    'string': 'string'
                }
            },
        ]
    }
}


Response Structure

(dict) --
Result structure used for requests of project details.

details (dict) --
Detailed information about an AWS Mobile Hub project.

name (string) --
Name of the project.

projectId (string) --
Unique project identifier.

region (string) --
Default region to use for AWS resource creation in the AWS Mobile Hub project.

state (string) --
Synchronization state for a project.

createdDate (datetime) --
Date the project was created.

lastUpdatedDate (datetime) --
Date of the last modification of the project.

consoleUrl (string) --
Website URL for this project in the AWS Mobile Hub console.

resources (list) --
List of AWS resources associated with a project.

(dict) --
Information about an instance of an AWS resource associated with a project.

type (string) --
Simplified name for type of AWS resource (e.g., bucket is an Amazon S3 bucket).

name (string) --
Name of the AWS resource (e.g., for an Amazon S3 bucket this is the name of the bucket).

arn (string) --
AWS resource name which uniquely identifies the resource in AWS systems.

feature (string) --
Identifies which feature in AWS Mobile Hub is associated with this AWS resource.

attributes (dict) --
Key-value attribute pairs.

(string) --
Key part of key-value attribute pairs.

(string) --
Value part of key-value attribute pairs.

















Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException


    :return: {
        'details': {
            'name': 'string',
            'projectId': 'string',
            'region': 'string',
            'state': 'NORMAL'|'SYNCING'|'IMPORTING',
            'createdDate': datetime(2015, 1, 1),
            'lastUpdatedDate': datetime(2015, 1, 1),
            'consoleUrl': 'string',
            'resources': [
                {
                    'type': 'string',
                    'name': 'string',
                    'arn': 'string',
                    'feature': 'string',
                    'attributes': {
                        'string': 'string'
                    }
                },
            ]
        }
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    Mobile.Client.exceptions.NotFoundException
    
    """
    pass

def export_bundle(bundleId=None, projectId=None, platform=None):
    """
    Generates customized software development kit (SDK) and or tool packages used to integrate mobile web or mobile app clients with backend AWS resources.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.export_bundle(
        bundleId='string',
        projectId='string',
        platform='OSX'|'WINDOWS'|'LINUX'|'OBJC'|'SWIFT'|'ANDROID'|'JAVASCRIPT'
    )
    
    
    :type bundleId: string
    :param bundleId: [REQUIRED]\nUnique bundle identifier.\n

    :type projectId: string
    :param projectId: Unique project identifier.

    :type platform: string
    :param platform: Developer desktop or target application platform.

    :rtype: dict

ReturnsResponse Syntax
{
    'downloadUrl': 'string'
}


Response Structure

(dict) --
Result structure which contains link to download custom-generated SDK and tool packages used to integrate mobile web or app clients with backed AWS resources.

downloadUrl (string) --
URL which contains the custom-generated SDK and tool packages used to integrate the client mobile app or web app with the AWS resources created by the AWS Mobile Hub project.







Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException


    :return: {
        'downloadUrl': 'string'
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    Mobile.Client.exceptions.NotFoundException
    
    """
    pass

def export_project(projectId=None):
    """
    Exports project configuration to a snapshot which can be downloaded and shared. Note that mobile app push credentials are encrypted in exported projects, so they can only be shared successfully within the same AWS account.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.export_project(
        projectId='string'
    )
    
    
    :type projectId: string
    :param projectId: [REQUIRED]\nUnique project identifier.\n

    :rtype: dict
ReturnsResponse Syntax{
    'downloadUrl': 'string',
    'shareUrl': 'string',
    'snapshotId': 'string'
}


Response Structure

(dict) --Result structure used for requests to export project configuration details.

downloadUrl (string) --URL which can be used to download the exported project configuation file(s).

shareUrl (string) --URL which can be shared to allow other AWS users to create their own project in AWS Mobile Hub with the same configuration as the specified project. This URL pertains to a snapshot in time of the project configuration that is created when this API is called. If you want to share additional changes to your project configuration, then you will need to create and share a new snapshot by calling this method again.

snapshotId (string) --Unique identifier for the exported snapshot of the project configuration. This snapshot identifier is included in the share URL.






Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException


    :return: {
        'downloadUrl': 'string',
        'shareUrl': 'string',
        'snapshotId': 'string'
    }
    
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_bundles(maxResults=None, nextToken=None):
    """
    List all available bundles.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_bundles(
        maxResults=123,
        nextToken='string'
    )
    
    
    :type maxResults: integer
    :param maxResults: Maximum number of records to list in a single response.

    :type nextToken: string
    :param nextToken: Pagination token. Set to null to start listing bundles from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more bundles.

    :rtype: dict

ReturnsResponse Syntax
{
    'bundleList': [
        {
            'bundleId': 'string',
            'title': 'string',
            'version': 'string',
            'description': 'string',
            'iconUrl': 'string',
            'availablePlatforms': [
                'OSX'|'WINDOWS'|'LINUX'|'OBJC'|'SWIFT'|'ANDROID'|'JAVASCRIPT',
            ]
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --
Result structure contains a list of all available bundles with details.

bundleList (list) --
A list of bundles.

(dict) --
The details of the bundle.

bundleId (string) --
Unique bundle identifier.

title (string) --
Title of the download bundle.

version (string) --
Version of the download bundle.

description (string) --
Description of the download bundle.

iconUrl (string) --
Icon for the download bundle.

availablePlatforms (list) --
Developer desktop or mobile app or website platforms.

(string) --
Developer desktop or target mobile app or website platform.







nextToken (string) --
Pagination token. If non-null pagination token is returned in a result, then pass its value in another request to fetch more entries.







Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException


    :return: {
        'bundleList': [
            {
                'bundleId': 'string',
                'title': 'string',
                'version': 'string',
                'description': 'string',
                'iconUrl': 'string',
                'availablePlatforms': [
                    'OSX'|'WINDOWS'|'LINUX'|'OBJC'|'SWIFT'|'ANDROID'|'JAVASCRIPT',
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    
    """
    pass

def list_projects(maxResults=None, nextToken=None):
    """
    Lists projects in AWS Mobile Hub.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_projects(
        maxResults=123,
        nextToken='string'
    )
    
    
    :type maxResults: integer
    :param maxResults: Maximum number of records to list in a single response.

    :type nextToken: string
    :param nextToken: Pagination token. Set to null to start listing projects from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more projects.

    :rtype: dict

ReturnsResponse Syntax
{
    'projects': [
        {
            'name': 'string',
            'projectId': 'string'
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --
Result structure used for requests to list projects in AWS Mobile Hub.

projects (list) --
List of projects.

(dict) --
Summary information about an AWS Mobile Hub project.

name (string) --
Name of the project.

projectId (string) --
Unique project identifier.





nextToken (string) --
Pagination token. Set to null to start listing records from start. If non-null pagination token is returned in a result, then pass its value in here in another request to list more entries.







Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException


    :return: {
        'projects': [
            {
                'name': 'string',
                'projectId': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    
    """
    pass

def update_project(contents=None, projectId=None):
    """
    Update an existing project.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.update_project(
        contents=b'bytes'|file,
        projectId='string'
    )
    
    
    :type contents: bytes or seekable file-like object
    :param contents: ZIP or YAML file which contains project configuration to be updated. This should be the contents of the file downloaded from the URL provided in an export project operation.

    :type projectId: string
    :param projectId: [REQUIRED]\nUnique project identifier.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'details': {
        'name': 'string',
        'projectId': 'string',
        'region': 'string',
        'state': 'NORMAL'|'SYNCING'|'IMPORTING',
        'createdDate': datetime(2015, 1, 1),
        'lastUpdatedDate': datetime(2015, 1, 1),
        'consoleUrl': 'string',
        'resources': [
            {
                'type': 'string',
                'name': 'string',
                'arn': 'string',
                'feature': 'string',
                'attributes': {
                    'string': 'string'
                }
            },
        ]
    }
}


Response Structure

(dict) --
Result structure used for requests to updated project configuration.

details (dict) --
Detailed information about the updated AWS Mobile Hub project.

name (string) --
Name of the project.

projectId (string) --
Unique project identifier.

region (string) --
Default region to use for AWS resource creation in the AWS Mobile Hub project.

state (string) --
Synchronization state for a project.

createdDate (datetime) --
Date the project was created.

lastUpdatedDate (datetime) --
Date of the last modification of the project.

consoleUrl (string) --
Website URL for this project in the AWS Mobile Hub console.

resources (list) --
List of AWS resources associated with a project.

(dict) --
Information about an instance of an AWS resource associated with a project.

type (string) --
Simplified name for type of AWS resource (e.g., bucket is an Amazon S3 bucket).

name (string) --
Name of the AWS resource (e.g., for an Amazon S3 bucket this is the name of the bucket).

arn (string) --
AWS resource name which uniquely identifies the resource in AWS systems.

feature (string) --
Identifies which feature in AWS Mobile Hub is associated with this AWS resource.

attributes (dict) --
Key-value attribute pairs.

(string) --
Key part of key-value attribute pairs.

(string) --
Value part of key-value attribute pairs.

















Exceptions

Mobile.Client.exceptions.InternalFailureException
Mobile.Client.exceptions.ServiceUnavailableException
Mobile.Client.exceptions.UnauthorizedException
Mobile.Client.exceptions.TooManyRequestsException
Mobile.Client.exceptions.BadRequestException
Mobile.Client.exceptions.NotFoundException
Mobile.Client.exceptions.AccountActionRequiredException
Mobile.Client.exceptions.LimitExceededException


    :return: {
        'details': {
            'name': 'string',
            'projectId': 'string',
            'region': 'string',
            'state': 'NORMAL'|'SYNCING'|'IMPORTING',
            'createdDate': datetime(2015, 1, 1),
            'lastUpdatedDate': datetime(2015, 1, 1),
            'consoleUrl': 'string',
            'resources': [
                {
                    'type': 'string',
                    'name': 'string',
                    'arn': 'string',
                    'feature': 'string',
                    'attributes': {
                        'string': 'string'
                    }
                },
            ]
        }
    }
    
    
    :returns: 
    Mobile.Client.exceptions.InternalFailureException
    Mobile.Client.exceptions.ServiceUnavailableException
    Mobile.Client.exceptions.UnauthorizedException
    Mobile.Client.exceptions.TooManyRequestsException
    Mobile.Client.exceptions.BadRequestException
    Mobile.Client.exceptions.NotFoundException
    Mobile.Client.exceptions.AccountActionRequiredException
    Mobile.Client.exceptions.LimitExceededException
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def batch_put_message(messages=None):
    """
    Sends a set of messages to the AWS IoT Events system. Each message payload is transformed into the input you specify ("inputName" ) and ingested into any detectors that monitor that input. If multiple messages are sent, the order in which the messages are processed isn\'t guaranteed. To guarantee ordering, you must send messages one at a time and wait for a successful response.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.batch_put_message(
        messages=[
            {
                'messageId': 'string',
                'inputName': 'string',
                'payload': b'bytes'
            },
        ]
    )
    
    
    :type messages: list
    :param messages: [REQUIRED]\nThe list of messages to send. Each message has the following format: \'{ 'messageId': 'string', 'inputName': 'string', 'payload': 'string'}\'\n\n(dict) --Information about a message.\n\nmessageId (string) -- [REQUIRED]The ID to assign to the message. Within each batch sent, each 'messageId' must be unique.\n\ninputName (string) -- [REQUIRED]The name of the input into which the message payload is transformed.\n\npayload (bytes) -- [REQUIRED]The payload of the message. This can be a JSON string or a Base-64-encoded string representing binary data (in which case you must decode it).\n\n\n\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'BatchPutMessageErrorEntries': [
        {
            'messageId': 'string',
            'errorCode': 'ResourceNotFoundException'|'InvalidRequestException'|'InternalFailureException'|'ServiceUnavailableException'|'ThrottlingException',
            'errorMessage': 'string'
        },
    ]
}


Response Structure

(dict) --
BatchPutMessageErrorEntries (list) --A list of any errors encountered when sending the messages.

(dict) --Contains information about the errors encountered.

messageId (string) --The ID of the message that caused the error. (See the value corresponding to the "messageId" key in the "message" object.)

errorCode (string) --The code associated with the error.

errorMessage (string) --More information about the error.










Exceptions

IoTEventsData.Client.exceptions.InvalidRequestException
IoTEventsData.Client.exceptions.InternalFailureException
IoTEventsData.Client.exceptions.ServiceUnavailableException
IoTEventsData.Client.exceptions.ThrottlingException


    :return: {
        'BatchPutMessageErrorEntries': [
            {
                'messageId': 'string',
                'errorCode': 'ResourceNotFoundException'|'InvalidRequestException'|'InternalFailureException'|'ServiceUnavailableException'|'ThrottlingException',
                'errorMessage': 'string'
            },
        ]
    }
    
    
    """
    pass

def batch_update_detector(detectors=None):
    """
    Updates the state, variable values, and timer settings of one or more detectors (instances) of a specified detector model.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.batch_update_detector(
        detectors=[
            {
                'messageId': 'string',
                'detectorModelName': 'string',
                'keyValue': 'string',
                'state': {
                    'stateName': 'string',
                    'variables': [
                        {
                            'name': 'string',
                            'value': 'string'
                        },
                    ],
                    'timers': [
                        {
                            'name': 'string',
                            'seconds': 123
                        },
                    ]
                }
            },
        ]
    )
    
    
    :type detectors: list
    :param detectors: [REQUIRED]\nThe list of detectors (instances) to update, along with the values to update.\n\n(dict) --Information used to update the detector (instance).\n\nmessageId (string) -- [REQUIRED]The ID to assign to the detector update 'message' . Each 'messageId' must be unique within each batch sent.\n\ndetectorModelName (string) -- [REQUIRED]The name of the detector model that created the detectors (instances).\n\nkeyValue (string) --The value of the input key attribute (identifying the device or system) that caused the creation of this detector (instance).\n\nstate (dict) -- [REQUIRED]The new state, variable values, and timer settings of the detector (instance).\n\nstateName (string) -- [REQUIRED]The name of the new state of the detector (instance).\n\nvariables (list) -- [REQUIRED]The new values of the detector\'s variables. Any variable whose value isn\'t specified is cleared.\n\n(dict) --The new value of the variable.\n\nname (string) -- [REQUIRED]The name of the variable.\n\nvalue (string) -- [REQUIRED]The new value of the variable.\n\n\n\n\n\ntimers (list) -- [REQUIRED]The new values of the detector\'s timers. Any timer whose value isn\'t specified is cleared, and its timeout event won\'t occur.\n\n(dict) --The new setting of a timer.\n\nname (string) -- [REQUIRED]The name of the timer.\n\nseconds (integer) -- [REQUIRED]The new setting of the timer (the number of seconds before the timer elapses).\n\n\n\n\n\n\n\n\n\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'batchUpdateDetectorErrorEntries': [
        {
            'messageId': 'string',
            'errorCode': 'ResourceNotFoundException'|'InvalidRequestException'|'InternalFailureException'|'ServiceUnavailableException'|'ThrottlingException',
            'errorMessage': 'string'
        },
    ]
}


Response Structure

(dict) --
batchUpdateDetectorErrorEntries (list) --A list of those detector updates that resulted in errors. (If an error is listed here, the specific update did not occur.)

(dict) --Information about the error that occured when attempting to update a detector.

messageId (string) --The "messageId" of the update request that caused the error. (The value of the "messageId" in the update request "Detector" object.)

errorCode (string) --The code of the error.

errorMessage (string) --A message describing the error.










Exceptions

IoTEventsData.Client.exceptions.InvalidRequestException
IoTEventsData.Client.exceptions.InternalFailureException
IoTEventsData.Client.exceptions.ServiceUnavailableException
IoTEventsData.Client.exceptions.ThrottlingException


    :return: {
        'batchUpdateDetectorErrorEntries': [
            {
                'messageId': 'string',
                'errorCode': 'ResourceNotFoundException'|'InvalidRequestException'|'InternalFailureException'|'ServiceUnavailableException'|'ThrottlingException',
                'errorMessage': 'string'
            },
        ]
    }
    
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def describe_detector(detectorModelName=None, keyValue=None):
    """
    Returns information about the specified detector (instance).
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_detector(
        detectorModelName='string',
        keyValue='string'
    )
    
    
    :type detectorModelName: string
    :param detectorModelName: [REQUIRED]\nThe name of the detector model whose detectors (instances) you want information about.\n

    :type keyValue: string
    :param keyValue: A filter used to limit results to detectors (instances) created because of the given key ID.

    :rtype: dict

ReturnsResponse Syntax
{
    'detector': {
        'detectorModelName': 'string',
        'keyValue': 'string',
        'detectorModelVersion': 'string',
        'state': {
            'stateName': 'string',
            'variables': [
                {
                    'name': 'string',
                    'value': 'string'
                },
            ],
            'timers': [
                {
                    'name': 'string',
                    'timestamp': datetime(2015, 1, 1)
                },
            ]
        },
        'creationTime': datetime(2015, 1, 1),
        'lastUpdateTime': datetime(2015, 1, 1)
    }
}


Response Structure

(dict) --

detector (dict) --
Information about the detector (instance).

detectorModelName (string) --
The name of the detector model that created this detector (instance).

keyValue (string) --
The value of the key (identifying the device or system) that caused the creation of this detector (instance).

detectorModelVersion (string) --
The version of the detector model that created this detector (instance).

state (dict) --
The current state of the detector (instance).

stateName (string) --
The name of the state.

variables (list) --
The current values of the detector\'s variables.

(dict) --
The current state of the variable.

name (string) --
The name of the variable.

value (string) --
The current value of the variable.





timers (list) --
The current state of the detector\'s timers.

(dict) --
The current state of a timer.

name (string) --
The name of the timer.

timestamp (datetime) --
The number of seconds which have elapsed on the timer.







creationTime (datetime) --
The time the detector (instance) was created.

lastUpdateTime (datetime) --
The time the detector (instance) was last updated.









Exceptions

IoTEventsData.Client.exceptions.InvalidRequestException
IoTEventsData.Client.exceptions.ResourceNotFoundException
IoTEventsData.Client.exceptions.ThrottlingException
IoTEventsData.Client.exceptions.InternalFailureException
IoTEventsData.Client.exceptions.ServiceUnavailableException


    :return: {
        'detector': {
            'detectorModelName': 'string',
            'keyValue': 'string',
            'detectorModelVersion': 'string',
            'state': {
                'stateName': 'string',
                'variables': [
                    {
                        'name': 'string',
                        'value': 'string'
                    },
                ],
                'timers': [
                    {
                        'name': 'string',
                        'timestamp': datetime(2015, 1, 1)
                    },
                ]
            },
            'creationTime': datetime(2015, 1, 1),
            'lastUpdateTime': datetime(2015, 1, 1)
        }
    }
    
    
    :returns: 
    IoTEventsData.Client.exceptions.InvalidRequestException
    IoTEventsData.Client.exceptions.ResourceNotFoundException
    IoTEventsData.Client.exceptions.ThrottlingException
    IoTEventsData.Client.exceptions.InternalFailureException
    IoTEventsData.Client.exceptions.ServiceUnavailableException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_detectors(detectorModelName=None, stateName=None, nextToken=None, maxResults=None):
    """
    Lists detectors (the instances of a detector model).
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_detectors(
        detectorModelName='string',
        stateName='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type detectorModelName: string
    :param detectorModelName: [REQUIRED]\nThe name of the detector model whose detectors (instances) are listed.\n

    :type stateName: string
    :param stateName: A filter that limits results to those detectors (instances) in the given state.

    :type nextToken: string
    :param nextToken: The token for the next set of results.

    :type maxResults: integer
    :param maxResults: The maximum number of results to return at one time.

    :rtype: dict

ReturnsResponse Syntax
{
    'detectorSummaries': [
        {
            'detectorModelName': 'string',
            'keyValue': 'string',
            'detectorModelVersion': 'string',
            'state': {
                'stateName': 'string'
            },
            'creationTime': datetime(2015, 1, 1),
            'lastUpdateTime': datetime(2015, 1, 1)
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --

detectorSummaries (list) --
A list of summary information about the detectors (instances).

(dict) --
Information about the detector (instance).

detectorModelName (string) --
The name of the detector model that created this detector (instance).

keyValue (string) --
The value of the key (identifying the device or system) that caused the creation of this detector (instance).

detectorModelVersion (string) --
The version of the detector model that created this detector (instance).

state (dict) --
The current state of the detector (instance).

stateName (string) --
The name of the state.



creationTime (datetime) --
The time the detector (instance) was created.

lastUpdateTime (datetime) --
The time the detector (instance) was last updated.





nextToken (string) --
A token to retrieve the next set of results, or null if there are no additional results.







Exceptions

IoTEventsData.Client.exceptions.InvalidRequestException
IoTEventsData.Client.exceptions.ResourceNotFoundException
IoTEventsData.Client.exceptions.ThrottlingException
IoTEventsData.Client.exceptions.InternalFailureException
IoTEventsData.Client.exceptions.ServiceUnavailableException


    :return: {
        'detectorSummaries': [
            {
                'detectorModelName': 'string',
                'keyValue': 'string',
                'detectorModelVersion': 'string',
                'state': {
                    'stateName': 'string'
                },
                'creationTime': datetime(2015, 1, 1),
                'lastUpdateTime': datetime(2015, 1, 1)
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    IoTEventsData.Client.exceptions.InvalidRequestException
    IoTEventsData.Client.exceptions.ResourceNotFoundException
    IoTEventsData.Client.exceptions.ThrottlingException
    IoTEventsData.Client.exceptions.InternalFailureException
    IoTEventsData.Client.exceptions.ServiceUnavailableException
    
    """
    pass

